@@ -1,6 +1,6 @@
 /*
  * GNUsound - a sound editor for GNOME.
- * Copyright (C) 2002-2004  Pascal Haakmat <a.haakmat@chello.nl>
+ * Copyright (C) 2002-2005  Pascal Haakmat <pascal@gnu.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,6 +31,8 @@
 #include "dialog_format_save.h"
 #include "dialog_format_mixdown.h"
 
+#define DIR_SEPARATOR "/"
+
 static int untitled_counter = 1;
 static char untitled_name[20];
 static char *path_open = NULL;
@@ -132,15 +134,35 @@ cmd_file_request_close_document(const char *name,
 static void
 cmd_file_open_selected(const char *filename,
                        void *user_data) {
+    char *tmp;
     struct file *file = file_new(filename);
     if(!file) 
         return;
 
-    if(path_open)
+    if(path_open) {
         free(path_open);
+        path_open = NULL;
+    }
+
+    if(filename) {
 
-    if(filename)
         path_open = g_path_get_dirname(filename);
+        tmp = mem_alloc(strlen(path_open) + strlen(DIR_SEPARATOR) + 1);
+        
+        if(tmp) {
+
+            sprintf(tmp, "%s%s", path_open, DIR_SEPARATOR);
+            free(path_open);
+            path_open = tmp;
+
+        } else {
+
+            free(path_open);
+            path_open = NULL;
+
+        }
+
+    }
 
     arbiter_queue_cmd(CMD_NEW("open-file", 
                               cmd_new_filep_val_with_dtor(file, 
@@ -253,6 +275,11 @@ cmd_file_save_file_selected(const char *filename,
         return;
     }
 
+    if(path_save) {
+        free(path_save);
+        path_save = NULL;
+    }
+
     path_save = g_strdup(filename);
 
     arbiter_queue_cmd(CMD_NEW("select-format-and-save", 
