@@ -1,6 +1,6 @@
 /*
  * GNUsound - a sound editor for GNOME.
- * Copyright (C) 2002-2005  Pascal Haakmat <a.haakmat@chello.nl>
+ * Copyright (C) 2002-2005  Pascal Haakmat <pascal@gnu.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,6 +20,9 @@
 
 /* FIXME: This file needs documentation.  Really. */
 
+#undef GTK_DISABLE_DEPRECATED
+#undef GNOME_DISABLE_DEPRECATED
+
 #include <stdlib.h>
 #include <string.h>
 #include <glib.h>
