@@ -269,25 +269,27 @@ mixer_mixn(mixer *m,
  * 
  * @param m The mixer object.
  * @param sample_type The type of the samples in the buffers.
- * @param fb_target The target buffer,must be big enough
- * to hold m->output_channels channels.
+ * @param fb_target The target buffer, must be big enough
+ * to hold frame_count * m->output_channels samples.
  * @param fb_sources Pointer array of input channels, must contain
  * m->source_tracks channels.
- * @param frame_count The number of frames to mix.
+ * @param frame_count The number of samples to mix.
  */
 
-#define MIXI(type)                              \
-  for(i = 0; i < frame_count; i++) {            \
-      for(j = 0; j < m->output_channels; j++) { \
-          for(k = 0; k < m->source_tracks; k++) \
-              ((type *)fb_target)[(i * m->output_channels) + j] += \
-                  (float)((int)((type **)fb_sources)[k][i] & \
-                          (m->num_solos ?       \
-                           m->source_is_solo[k] : \
-                           m->source_is_mute[k])) * \
-                  m->mixtable[j][k];            \
-      } \
-  }
+#define MIXI(type) \
+  for(j = 0; j < m->output_channels; j++) { \
+    for(k = 0; k < m->source_tracks; k++) { \
+        if(m->num_solos > 0 && !m->source_is_solo[k]) { \
+            continue; \
+        } else if(m->source_is_mute[k]) { \
+            continue; \
+        } \
+        for(i = 0; i < frame_count; i++) { \
+            ((type *)fb_target)[(i * m->output_channels) + j] += \
+                ((type **)fb_sources)[k][i] * m->mixtable[j][k]; \
+        } \
+    } \
+  } \
 
 inline void
 mixer_mixi(mixer *m,
@@ -331,8 +333,6 @@ mixer_mixi(mixer *m,
  * @param frame_count The number of frames to mix.
  */
 
-/* FIXME: don't do work for muted or silent channels. */
-
 #define MIXN(type) \
   for(j = 0; j < m->output_channels; j++) { \
     for(k = 0; k < m->source_tracks; k++) { \
